@@ -671,7 +671,7 @@ getconfig(
 			minpoll = NTP_MINDPOLL;
 			maxpoll = NTP_MAXDPOLL;
 			peerkey = 0;
-			peerkeystr = "*";
+			peerkeystr = (u_char *)"*";
 			peerflags = 0;
 			ttl = 0;
 			for (i = 2; i < ntokens; i++)
@@ -1801,7 +1801,7 @@ gettokens_netinfo (
 				for (index = 0; index < namelist.ni_namelist_len; index++) {
 					char *value = namelist.ni_namelist_val[index];
 
-					if (! (val_list[index] = (char*)malloc(strlen(value+1))))
+					if (! (val_list[index] = (char*)malloc(strlen(value)+1)))
 						{ msyslog(LOG_ERR, "out of memory while configuring"); break; }
 
 					strcpy(val_list[index], value);
@@ -2006,7 +2006,10 @@ getnetnum(
 #ifdef DEBUG
 		if (debug > 3)
 			printf(
-				"getnetnum: \"%s\" invalid host number, line ignored\n",
+				"getnetnum: \"%s\" invalid host number%s.\n",
+				(complain)
+				? ", line ignored"
+				: "",
 				num);
 #endif
 		return 0;
@@ -2211,7 +2214,7 @@ do_resolve_internal(void)
 		 */
 
 		closelog();
-		kill_asyncio();
+		kill_asyncio(0);
 
 		(void) signal_no_reset(SIGCHLD, SIG_DFL);
 
