@@ -142,6 +142,7 @@ static	int open_socket		P((struct sockaddr_in *, int, int));
 static	void	close_socket	P((int));
 static	void	close_file	P((int));
 static	char *	fdbits		P((int, fd_set *));
+static	void	set_reuseaddr	P((int));
 
 /*
  * init_io - initialize I/O data structures and call socket creation routine
@@ -615,21 +616,7 @@ create_sockets(
 	 * Now that we have opened all the sockets, turn off the reuse flag for
 	 * security.
 	 */
-	for (i = 0; i < ninterfaces; i++) {
-		int off = 0;
-
-		/*
-		 * if inter_list[ n ].fd  is -1, we might have a adapter
-		 * configured but not present
-		 */
-		if ( inter_list[ i ].fd != -1 ) {
-			if (setsockopt(inter_list[i].fd, SOL_SOCKET,
-				       SO_REUSEADDR, (char *)&off,
-				       sizeof(off))) {
-				msyslog(LOG_ERR, "create_sockets: setsockopt(SO_REUSEADDR,off) failed: %m");
-			}
-		}
-	}
+	set_reuseaddr(0);
 
 #if defined(MCAST)
 	/*
@@ -684,6 +671,10 @@ io_setbclient(void)
 {
 	int i;
 
+#ifdef OPEN_BCAST_SOCKET
+	set_reuseaddr(1);
+#endif
+
 	for (i = 1; i < ninterfaces; i++) {
 		if (!(inter_list[i].flags & INT_BROADCAST))
 			continue;
@@ -700,6 +691,34 @@ io_setbclient(void)
 		inter_list[i].flags |= INT_BCASTOPEN;
 #endif
 	}
+
+#ifdef OPEN_BCAST_SOCKET
+	set_reuseaddr(0);
+#endif
+}
+
+/*
+ * set_reuseaddr() - set/clear REUSEADDR on all sockets
+ *		NB possible hole - should we be doing this on broadcast
+ *			fd's also?
+ */
+static void
+set_reuseaddr(int flag) {
+	int i;
+
+	for (i = 0; i < ninterfaces; i++) {
+		/*
+		 * if inter_list[ n ].fd  is -1, we might have a adapter
+		 * configured but not present
+		 */
+		if ( inter_list[ i ].fd != -1 ) {
+			if (setsockopt(inter_list[i].fd, SOL_SOCKET,
+				       SO_REUSEADDR, (char *)&flag,
+				       sizeof(flag))) {
+				msyslog(LOG_ERR, "create_sockets: setsockopt(SO_REUSEADDR,%s) failed: %m", flag ? "on" : "off");
+			}
+		}
+	}
 }
 
 
@@ -747,7 +766,9 @@ io_multicast_add(
 	 * Try opening a socket for the specified class D address. This
 	 * works under SunOS 4.x, but not OSF1 .. :-(
 	 */
+	set_reuseaddr(1);
 	s = open_socket(sinp, 0, 1);
+	set_reuseaddr(0);
 	if (s < 0) {
 		memset((char *)&inter_list[i], 0, sizeof inter_list[0]);
 		i = 0;
@@ -1516,8 +1537,11 @@ input_handler(
 			/*
 			 * extended FAU debugging output
 			 */
-			msyslog(LOG_ERR, "select(%d, %s, 0L, 0L, &0.000000) error: %m",
-				maxactivefd+1, fdbits(maxactivefd, &activefds));
+			if (err != EINTR)
+			    msyslog(LOG_ERR,
+				    "select(%d, %s, 0L, 0L, &0.0) error: %m",
+				    maxactivefd+1,
+				    fdbits(maxactivefd, &activefds));
 			if (err == EBADF) {
 				int j, b;
 
@@ -1752,11 +1776,13 @@ io_closeclock(
 #endif	/* REFCLOCK */
 
 void
-kill_asyncio(void)
+kill_asyncio(
+	int startfd
+	)
 {
 	int i;
 
 	BLOCKIO();
-	for (i = 0; i <= maxactivefd; i++)
+	for (i = startfd; i <= maxactivefd; i++)
 	    (void)close_socket(i);
 }
