@@ -384,6 +384,9 @@ ntpdmain(
 #endif
 	getstartup(argc, argv); /* startup configuration, may set debug */
 
+	if (debug)
+	    printf("%s\n", Version);
+
 	/*
 	 * Initialize random generator and public key pair
 	 */
@@ -414,12 +417,12 @@ ntpdmain(
 			int max_fd;
 #endif /* not F_CLOSEM */
 
+#if defined(F_CLOSEM)
 			/*
 			 * From 'Writing Reliable AIX Daemons,' SG24-4946-00,
 			 * by Eric Agar (saves us from doing 32767 system
 			 * calls)
 			 */
-#if defined(F_CLOSEM)
 			if (fcntl(0, F_CLOSEM, 0) == -1)
 			    msyslog(LOG_ERR, "ntpd: failed to close open files(): %m");
 #else  /* not F_CLOSEM */
@@ -900,9 +903,10 @@ service_main(
 			}
 			else if (nfound == -1 && errno != EINTR)
 				msyslog(LOG_ERR, "select() error: %m");
-			else if (debug > 2) {
+#  ifdef DEBUG
+			else if (debug > 2)
 				msyslog(LOG_DEBUG, "select(): nfound=%d, error: %m", nfound);
-			}
+#  endif /* DEBUG */
 # else /* HAVE_SIGNALED_IO */
                         
 			wait_for_signal();
