@@ -88,6 +88,16 @@ struct refclock refclock_palisade = {
 
 int day_of_year P((char *dt));
 
+/* Extract the clock type from the mode setting */
+#define CLK_TYPE(x) ((int)(((x)->ttlmax) & 0x7F))
+
+/* Supported clock types */
+#define CLK_TRIMBLE	0	/* Trimble Palisade */
+#define CLK_PRAECIS	1	/* Endrun Technologies Praecis */
+
+int praecis_msg;
+static void praecis_parse(struct recvbuf *rbufp, struct peer *peer);
+
 /*
  * palisade_start - open the devices and initialize data for processing
  */
@@ -195,6 +205,19 @@ palisade_start (
 
 	memset((char *)up, 0, sizeof(struct palisade_unit));
 
+	up->type = CLK_TYPE(peer);
+	switch (up->type) {
+		case CLK_TRIMBLE:
+			/* Normal mode, do nothing */
+			break;
+		case CLK_PRAECIS:
+			msyslog(LOG_NOTICE, "Palisade(%d) Praecis mode enabled\n",unit);
+			break;
+		default:
+			msyslog(LOG_NOTICE, "Palisade(%d) mode unknown\n",unit);
+			break;
+	}
+
 	pp = peer->procptr;
 	pp->io.clock_recv = palisade_io;
 	pp->io.srcclock = (caddr_t)peer;
@@ -620,10 +643,43 @@ palisade_poll (
 	if (pp->sloppyclockflag & CLK_FLAG2) 
 	    return;  /* using synchronous packet input */
 
+	if(up->type == CLK_PRAECIS) {
+		if(write(peer->procptr->io.fd,"SPSTAT\r\n",8) < 0)
+			msyslog(LOG_ERR, "Palisade(%d) write: %m:",unit);
+		else {
+			praecis_msg = 1;
+			return;
+		}
+	}
+
 	if (HW_poll(pp) < 0) 
 	    refclock_report(peer, CEVNT_FAULT); 
 }
 
+static void
+praecis_parse(struct recvbuf *rbufp, struct peer *peer)
+{
+	static char buf[100];
+	static int p = 0;
+	struct refclockproc *pp;
+
+	pp = peer->procptr;
+
+	memcpy(buf+p,rbufp->recv_space.X_recv_buffer, rbufp->recv_length);
+	p += rbufp->recv_length;
+
+	if(buf[p-2] == '\r' && buf[p-1] == '\n') {
+		buf[p-2] = '\0';
+		record_clock_stats(&peer->srcadr, buf);
+
+		p = 0;
+		praecis_msg = 0;
+
+		if (HW_poll(pp) < 0)
+			refclock_report(peer, CEVNT_FAULT);
+
+	}
+}
 
 static void
 palisade_io (
@@ -649,6 +705,13 @@ palisade_io (
 	pp = peer->procptr;
 	up = (struct palisade_unit *)pp->unitptr;
 
+	if(up->type == CLK_PRAECIS) {
+		if(praecis_msg) {
+			praecis_parse(rbufp,peer);
+			return;
+		}
+	}
+
 	c = (char *) &rbufp->recv_space;
 	d = c + rbufp->recv_length;
 		
